==> constructive_0.2.0.tar.gz: constructive/tests/testthat/_snaps/construct_multi.md <==
# construct_multi

    Code
      construct_multi(list(a = letters, b = .leap.seconds))
    Output
      a <- c(
        "a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o",
        "p", "q", "r", "s", "t", "u", "v", "w", "x", "y", "z"
      )
      
      b <- as.POSIXct(
        c(
          "1972-07-01", "1973-01-01", "1974-01-01", "1975-01-01", "1976-01-01",
          "1977-01-01", "1978-01-01", "1979-01-01", "1980-01-01", "1981-07-01",
          "1982-07-01", "1983-07-01", "1985-07-01", "1988-01-01", "1990-01-01",
          "1991-01-01", "1992-07-01", "1993-07-01", "1994-07-01", "1996-01-01",
          "1997-07-01", "1999-01-01", "2006-01-01", "2009-01-01", "2012-07-01",
          "2015-07-01", "2017-01-01"
        ),
        tz = "GMT"
      )
      

---

    Code
      construct_multi(new_environment(list(a = letters, b = .leap.seconds)))
    Output
      a <- c(
        "a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o",
        "p", "q", "r", "s", "t", "u", "v", "w", "x", "y", "z"
      )
      
      b <- as.POSIXct(
        c(
          "1972-07-01", "1973-01-01", "1974-01-01", "1975-01-01", "1976-01-01",
          "1977-01-01", "1978-01-01", "1979-01-01", "1980-01-01", "1981-07-01",
          "1982-07-01", "1983-07-01", "1985-07-01", "1988-01-01", "1990-01-01",
          "1991-01-01", "1992-07-01", "1993-07-01", "1994-07-01", "1996-01-01",
          "1997-07-01", "1999-01-01", "2006-01-01", "2009-01-01", "2012-07-01",
          "2015-07-01", "2017-01-01"
        ),
        tz = "GMT"
      )

==> constructive_1.3.0.tar.gz: constructive/tests/testthat/_snaps/construct_multi.md <==
# construct_multi

    Code
      construct_multi(list(a = letters, b = .leap.seconds))
    Output
      a <- c(
        "a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o",
        "p", "q", "r", "s", "t", "u", "v", "w", "x", "y", "z"
      )
      
      b <- as.POSIXct(
        c(
          "1972-07-01", "1973-01-01", "1974-01-01", "1975-01-01", "1976-01-01",
          "1977-01-01", "1978-01-01", "1979-01-01", "1980-01-01", "1981-07-01",
          "1982-07-01", "1983-07-01", "1985-07-01", "1988-01-01", "1990-01-01",
          "1991-01-01", "1992-07-01", "1993-07-01", "1994-07-01", "1996-01-01",
          "1997-07-01", "1999-01-01", "2006-01-01", "2009-01-01", "2012-07-01",
          "2015-07-01", "2017-01-01"
        ),
        tz = "GMT"
      )
      

---

    Code
      construct_multi(new_environment(list(a = letters, b = .leap.seconds)))
    Output
      b <- as.POSIXct(
        c(
          "1972-07-01", "1973-01-01", "1974-01-01", "1975-01-01", "1976-01-01",
          "1977-01-01", "1978-01-01", "1979-01-01", "1980-01-01", "1981-07-01",
          "1982-07-01", "1983-07-01", "1985-07-01", "1988-01-01", "1990-01-01",
          "1991-01-01", "1992-07-01", "1993-07-01", "1994-07-01", "1996-01-01",
          "1997-07-01", "1999-01-01", "2006-01-01", "2009-01-01", "2012-07-01",
          "2015-07-01", "2017-01-01"
        ),
        tz = "GMT"
      )
      
      a <- c(
        "a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o",
        "p", "q", "r", "s", "t", "u", "v", "w", "x", "y", "z"
      )
      

---

    Code
      construct_multi(new_environment(list(a = letters, b = .leap.seconds)),
      include_dotted = FALSE)
    Output
      b <- as.POSIXct(
        c(
          "1972-07-01", "1973-01-01", "1974-01-01", "1975-01-01", "1976-01-01",
          "1977-01-01", "1978-01-01", "1979-01-01", "1980-01-01", "1981-07-01",
          "1982-07-01", "1983-07-01", "1985-07-01", "1988-01-01", "1990-01-01",
          "1991-01-01", "1992-07-01", "1993-07-01", "1994-07-01", "1996-01-01",
          "1997-07-01", "1999-01-01", "2006-01-01", "2009-01-01", "2012-07-01",
          "2015-07-01", "2017-01-01"
        ),
        tz = "GMT"
      )
      
      a <- c(
        "a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o",
        "p", "q", "r", "s", "t", "u", "v", "w", "x", "y", "z"
      )
      

---

    Code
      a <- 1
      foo <- (function(x, y) {
        force(x)
        "а" <- 2
        construct_multi(environment())
      })
      foo(a, a)
    Output
      delayedAssign(
        "y",
        value = a,
        eval.env = constructive::.env(
          "0x123456789",
          parents = c("0x123456789", "0x123456789", "namespace:constructive")
        )
      )
      x <- 1
      
      "\U{430}" <- 2
